summaryrefslogtreecommitdiffstats
path: root/mpvcore/player/timeline/tl_mpv_edl.c
diff options
context:
space:
mode:
Diffstat (limited to 'mpvcore/player/timeline/tl_mpv_edl.c')
-rw-r--r--mpvcore/player/timeline/tl_mpv_edl.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/mpvcore/player/timeline/tl_mpv_edl.c b/mpvcore/player/timeline/tl_mpv_edl.c
index 4c44ea9fc8..1f4bbc268e 100644
--- a/mpvcore/player/timeline/tl_mpv_edl.c
+++ b/mpvcore/player/timeline/tl_mpv_edl.c
@@ -268,8 +268,9 @@ void build_mpv_edl_timeline(struct MPContext *mpctx)
mp_msg(MSGT_CPLAYER, MSGL_ERR, "Error in EDL.\n");
return;
}
- // Don't allow arbitrary paths
- fix_filenames(parts, mpctx->demuxer->filename);
+ // Source is .edl and not edl:// => don't allow arbitrary paths
+ if (mpctx->demuxer->stream->uncached_type != STREAMTYPE_EDL)
+ fix_filenames(parts, mpctx->demuxer->filename);
build_timeline(mpctx, parts);
talloc_free(parts);
}